# -*- coding: utf-8 -*-

"""functions to scrape the stats pages of secondhandsongs.com
"""

from bs4 import BeautifulSoup
import urllib.request
import logging
import logging.config

from shsdl.utils import setup_logging

log = logging.getLogger(__name__)
setup_logging()

MCW_URL_FORMAT = 'https://secondhandsongs.com/statistics?id=stat-most-covered-song&offset={}'


def scrape_most_covered_works():
    """scrape most covered works stats page.

    Details in https://secondhandsongs.com/statistics/stat-most-covered-song?id=stat-most-covered-song

    :return: list of most covered works (work_id, count) tuples
    """
    log.info("start scraping most covered works")
    scrape_result = list()
    current_page = 0

    while True:

        log.info("scraping page {}".format(current_page))
        offset = current_page * 100
        url = MCW_URL_FORMAT.format(offset)
        contents = urllib.request.urlopen(url).read()
        soup = BeautifulSoup(contents, 'html.parser')

        # only 1 table in the entire page, directly locate tr tags
        # it's the end of the list if no table is found
        if not soup.table:
            log.info("last page reached")
            break
        rows = soup.table.find_all('tr')

        # first row is the column names, start from the second row
        for i in range(1, len(rows)):
            row = rows[i]
            rank_id, title, composer, singer, cover_count = row.find_all('td')
            song_id = int(title.a['href'].split("/")[-1])
            cover_count = int(cover_count.text.replace(" ", "").replace("\n", ""))
            log.debug("found work id: {}, cover count: {}".format(song_id, cover_count))
            scrape_result.append((song_id, cover_count))
        current_page += 1

    log.info("finished scraping most covered works, found {} works".format(len(scrape_result)))
    return scrape_result
